<?php
/**
 * The template to display single post
 *
 * @package WANDERIC
 * @since WANDERIC 1.0
 */

// Full post loading
$full_post_loading        = wanderic_get_value_gp( 'action' ) == 'full_post_loading';

// Prev post loading
$prev_post_loading        = wanderic_get_value_gp( 'action' ) == 'prev_post_loading';
$prev_post_loading_type   = wanderic_get_theme_option( 'posts_navigation_scroll_which_block' );

// Position of the related posts
$wanderic_related_position = wanderic_get_theme_option( 'related_position' );

// Type of the prev/next posts navigation
$wanderic_posts_navigation = wanderic_get_theme_option( 'posts_navigation' );
$wanderic_prev_post        = false;

// Rewrite style of the single post if current post loading via AJAX and featured image and title is not in the content
if ( ( $full_post_loading 
		|| 
		( $prev_post_loading && 'article' == $prev_post_loading_type )
	) 
	&& 
	! in_array( wanderic_get_theme_option( 'single_style' ), array( 'style-6' ) )
) {
	wanderic_storage_set_array( 'options_meta', 'single_style', 'style-6' );
}

get_header();

while ( have_posts() ) {

	the_post();

	// Type of the prev/next posts navigation
	if ( 'scroll' == $wanderic_posts_navigation ) {
		$wanderic_prev_post = get_previous_post( true );         // Get post from same category
		if ( ! $wanderic_prev_post ) {
			$wanderic_prev_post = get_previous_post( false );    // Get post from any category
			if ( ! $wanderic_prev_post ) {
				$wanderic_posts_navigation = 'links';
			}
		}
	}

	// Override some theme options to display featured image, title and post meta in the dynamic loaded posts
	if ( $full_post_loading || ( $prev_post_loading && $wanderic_prev_post ) ) {
		wanderic_sc_layouts_showed( 'featured', false );
		wanderic_sc_layouts_showed( 'title', false );
		wanderic_sc_layouts_showed( 'postmeta', false );
	}

	// If related posts should be inside the content
	if ( strpos( $wanderic_related_position, 'inside' ) === 0 ) {
		ob_start();
	}

	// Display post's content
	get_template_part( apply_filters( 'wanderic_filter_get_template_part', 'templates/content', 'single-' . wanderic_get_theme_option( 'single_style' ) ), 'single-' . wanderic_get_theme_option( 'single_style' ) );

	// If related posts should be inside the content
	if ( strpos( $wanderic_related_position, 'inside' ) === 0 ) {
		$wanderic_content = ob_get_contents();
		ob_end_clean();

		ob_start();
		do_action( 'wanderic_action_related_posts' );
		$wanderic_related_content = ob_get_contents();
		ob_end_clean();

		$wanderic_related_position_inside = max( 0, min( 9, wanderic_get_theme_option( 'related_position_inside' ) ) );
		if ( 0 == $wanderic_related_position_inside ) {
			$wanderic_related_position_inside = mt_rand( 1, 9 );
		}

		$wanderic_p_number = 0;
		$wanderic_related_inserted = false;
		for ( $i = 0; $i < strlen( $wanderic_content ) - 3; $i++ ) {
			if ( '<' == $wanderic_content[ $i ] && 'p' == $wanderic_content[ $i + 1 ] && in_array( $wanderic_content[ $i + 2 ], array( '>', ' ' ) ) ) {
				$wanderic_p_number++;
				if ( $wanderic_related_position_inside == $wanderic_p_number ) {
					$wanderic_related_inserted = true;
					$wanderic_content = ( $i > 0 ? substr( $wanderic_content, 0, $i ) : '' )
										. $wanderic_related_content
										. substr( $wanderic_content, $i );
				}
			}
		}
		if ( ! $wanderic_related_inserted ) {
			$wanderic_content .= $wanderic_related_content;
		}

		wanderic_show_layout( $wanderic_content );
	}

	// Comments
	do_action( 'wanderic_action_before_comments' );
	comments_template();
	do_action( 'wanderic_action_after_comments' );

	// Related posts
	if ( 'below_content' == $wanderic_related_position
		&& ( 'scroll' != $wanderic_posts_navigation || wanderic_get_theme_option( 'posts_navigation_scroll_hide_related' ) == 0 )
		&& ( ! $full_post_loading || wanderic_get_theme_option( 'open_full_post_hide_related' ) == 0 )
	) {
		do_action( 'wanderic_action_related_posts' );
	}

	// Post navigation: type 'scroll'
	if ( 'scroll' == $wanderic_posts_navigation && ! $full_post_loading ) {
		?>
		<div class="nav-links-single-scroll"
			data-post-id="<?php echo esc_attr( get_the_ID( $wanderic_prev_post ) ); ?>"
			data-post-link="<?php the_permalink( $wanderic_prev_post ); ?>"
			data-post-title="<?php the_title_attribute( array( 'post' => $wanderic_prev_post ) ); ?>">
		</div>
		<?php
	}
}

get_footer();
