<?php
/**
 * Skins support: Main skin file for the skin 'Default'
 *
 * Load scripts and styles,
 * and other operations that affect the appearance and behavior of the theme
 * when the skin is activated
 *
 * @package WANDERIC
 * @since WANDERIC 1.0.46
 */


// SKIN SETUP
//--------------------------------------------------------------------

// Setup fonts, colors, blog and single styles, etc.
$wanderic_skin_path = wanderic_get_file_dir( wanderic_skins_get_current_skin_dir() . 'skin-setup.php' );
if ( ! empty( $wanderic_skin_path ) ) {
	require_once $wanderic_skin_path;
}

// Skin options
$wanderic_skin_path = wanderic_get_file_dir( wanderic_skins_get_current_skin_dir() . 'skin-options.php' );
if ( ! empty( $wanderic_skin_path ) ) {
	require_once $wanderic_skin_path;
}

// Required plugins
$wanderic_skin_path = wanderic_get_file_dir( wanderic_skins_get_current_skin_dir() . 'skin-plugins.php' );
if ( ! empty( $wanderic_skin_path ) ) {
	require_once $wanderic_skin_path;
}

// Demo import
$wanderic_skin_path = wanderic_get_file_dir( wanderic_skins_get_current_skin_dir() . 'skin-demo-importer.php' );
if ( ! empty( $wanderic_skin_path ) ) {
	require_once $wanderic_skin_path;
}


// TRX_ADDONS SETUP
//--------------------------------------------------------------------

// Filter to add in the required plugins list
// Priority 11 to add new plugins to the end of the list
if ( ! function_exists( 'wanderic_skin_tgmpa_required_plugins' ) ) {
	add_filter( 'wanderic_filter_tgmpa_required_plugins', 'wanderic_skin_tgmpa_required_plugins', 11 );
	function wanderic_skin_tgmpa_required_plugins( $list = array() ) {
		// ToDo: Check if plugin is in the 'required_plugins' and add his parameters to the TGMPA-list
		//       Replace 'skin-specific-plugin-slug' to the real slug of the plugin
		if ( wanderic_storage_isset( 'required_plugins', 'skin-specific-plugin-slug' ) ) {
			$list[] = array(
				'name'     => wanderic_storage_get_array( 'required_plugins', 'skin-specific-plugin-slug', 'title' ),
				'slug'     => 'skin-specific-plugin-slug',
				'required' => false,
			);
		}
		return $list;
	}
}

// Filter to add/remove components of ThemeREX Addons when current skin is active
if ( ! function_exists( 'wanderic_skin_trx_addons_default_components' ) ) {
	add_filter('trx_addons_filter_load_options', 'wanderic_skin_trx_addons_default_components', 20);
	function wanderic_skin_trx_addons_default_components($components) {
		// ToDo: Set key value in the array $components to 0 (disable component) or 1 (enable component)
		//---> For example (enable reviews for posts):
		//---> $components['components_components_reviews'] = 1;
		return $components;
	}
}

// Filter to add/remove CPT
if ( ! function_exists( 'wanderic_skin_trx_addons_cpt_list' ) ) {
	add_filter('trx_addons_cpt_list', 'wanderic_skin_trx_addons_cpt_list');
	function wanderic_skin_trx_addons_cpt_list( $list = array() ) {
		// ToDo: Unset CPT slug from list to disable CPT when current skin is active
		//---> For example to disable CPT 'Portfolio':
		//---> unset( $list['portfolio'] );
		return $list;
	}
}

// Filter to add/remove shortcodes
if ( ! function_exists( 'wanderic_skin_trx_addons_sc_list' ) ) {
	add_filter('trx_addons_sc_list', 'wanderic_skin_trx_addons_sc_list');
	function wanderic_skin_trx_addons_sc_list( $list = array() ) {
		// ToDo: Unset shortcode's slug from list to disable shortcode when current skin is active
		//---> For example to disable shortcode 'Action':
		//---> unset( $list['action'] );

		// Also can be used to add/remove/modify shortcodes params
		//---> For example to add new template to the 'Blogger':
		//---> $list['blogger']['templates']['default']['new_template_slug'] = array(
		//--->		'title' => __('Title of the new template', 'wanderic'),
		//--->		'layout' => array(
		//--->			'featured' => array(),
		//--->			'content' => array('meta_categories', 'title', 'excerpt', 'meta', 'readmore')
		//--->		)
		//---> );
		return $list;
	}
}

// Filter to add/remove widgets
if ( ! function_exists( 'wanderic_skin_trx_addons_widgets_list' ) ) {
	add_filter('trx_addons_widgets_list', 'wanderic_skin_trx_addons_widgets_list');
	function wanderic_skin_trx_addons_widgets_list( $list = array() ) {
		// ToDo: Unset widget's slug from list to disable widget when current skin is active
		//---> For example to disable widget 'About Me':
		//---> unset( $list['aboutme'] );
		return $list;
	}
}



// SCRIPTS AND STYLES
//--------------------------------------------------

// Enqueue skin-specific scripts
// Priority 1050 -  before main theme plugins-specific (1100)
if ( ! function_exists( 'wanderic_skin_frontend_scripts' ) ) {
	add_action( 'wp_enqueue_scripts', 'wanderic_skin_frontend_scripts', 1050 );
	function wanderic_skin_frontend_scripts() {
		$wanderic_url = wanderic_get_file_url( wanderic_skins_get_current_skin_dir() . 'css/style.css' );
		if ( '' != $wanderic_url ) {
			wp_enqueue_style( 'wanderic-skin-' . esc_attr( wanderic_skins_get_current_skin_name() ), $wanderic_url, array(), null );
		}
		$wanderic_url = wanderic_get_file_url( wanderic_skins_get_current_skin_dir() . 'skin.js' );
		if ( '' != $wanderic_url ) {
			wp_enqueue_script( 'wanderic-skin-' . esc_attr( wanderic_skins_get_current_skin_name() ), $wanderic_url, array( 'jquery' ), null, true );
		}
	}
}


// Custom styles
$wanderic_style_path = wanderic_get_file_dir( wanderic_skins_get_current_skin_dir() . 'css/style.php' );
if ( ! empty( $wanderic_style_path ) ) {
	require_once $wanderic_style_path;
}
// Show single post footer: tags, likes and share
if ( ! function_exists( 'wanderic_skin_show_post_footer' ) ) {
    function wanderic_skin_show_post_footer( $components = 'pages,tags,share,likes,author,prev_next' ) {

        $components               = array_map( 'trim', explode( ',', $components ) );
        $meta_components          = wanderic_array_get_keys_by_value( wanderic_get_theme_option( 'meta_parts' ) );
        $share_position           = wanderic_array_get_keys_by_value( wanderic_get_theme_option( 'share_position' ) );

        $full_post_loading        = wanderic_get_value_gp( 'action' ) == 'full_post_loading';
        $wanderic_posts_navigation = wanderic_get_theme_option( 'posts_navigation' );

        if ( in_array('share', $meta_components ) || in_array('tags', $components ) ) {
            ?>
            <div class="footer_meta_wrap">
            <?php
                if( in_array('tags', $components ) ) {
                    // Post tags
                    the_tags( '<div class="post_tags_single"><span class="post_meta_label">' . esc_html__( 'Tags:', 'wanderic' ) . '</span> ', '', '</div>' );
                }
                if ( in_array('share', $meta_components ) && in_array( 'bottom', $share_position ) ) {
                    wanderic_show_post_meta(
                        array(
                            'components' => 'share',
                            'class'      => 'post_meta_share',
                            'share_type' => 'block'
                        )
                    );
                }
            ?>
            </div>
            <?php
        }


        foreach( $components as $comp ) {

            if ( 'likes' == $comp ) {

                // Emotions
                if ( wanderic_exists_trx_addons() && function_exists( 'trx_addons_get_post_reactions' ) && trx_addons_is_on( trx_addons_get_option( 'emotions_allowed' ) ) ) {
                    trx_addons_get_post_reactions( true );
                }

                // Likes and Share
                $meta_footer = array();
                if ( in_array( 'likes', $components ) && in_array( 'likes', $meta_components )
                    &&
                    ( ! function_exists( 'trx_addons_get_option' ) || trx_addons_is_off( trx_addons_get_option( 'emotions_allowed' ) ) || ! apply_filters( 'trx_addons_filter_show_post_reactions', is_single() && ! is_attachment() ) )
                ) {
                    $meta_footer[] = 'likes';
                }
                if ( count( $meta_footer) > 0 ) {
                    ob_start();
                    wanderic_show_post_meta(
                        apply_filters(
                            'wanderic_filter_post_meta_args',
                            array(
                                'components' => join( ',', $meta_footer ),
                                'class'      => 'post_meta_single',
                            ),
                            'single',
                            1
                        )
                    );
                    $wanderic_meta_output = ob_get_contents();
                    ob_end_clean();
                    if ( ! empty( $wanderic_meta_output ) ) {
                        do_action( 'wanderic_action_before_post_meta' );
                        wanderic_show_layout( $wanderic_meta_output );
                        do_action( 'wanderic_action_after_post_meta' );
                    }
                }

            } else if ( 'author' == $comp ) {

                // Author bio
                if ( wanderic_get_theme_option( 'show_author_info' ) == 1
                    && ! is_attachment()
                    && get_the_author_meta( 'description' )
                    && ( 'scroll' != $wanderic_posts_navigation || wanderic_get_theme_option( 'posts_navigation_scroll_hide_author' ) == 0 )
                    && ( ! $full_post_loading || wanderic_get_theme_option( 'open_full_post_hide_author' ) == 0 )
                ) {
                    do_action( 'wanderic_action_before_post_author' );
                    get_template_part( apply_filters( 'wanderic_filter_get_template_part', 'templates/author-bio' ) );
                    do_action( 'wanderic_action_after_post_author' );
                }

            } else if ( 'prev_next' == $comp ) {

                // Previous/next post navigation.
                if ( 'links' == $wanderic_posts_navigation && ! $full_post_loading ) {
                    do_action( 'wanderic_action_before_post_navigation' );
                    ?>
                    <div class="nav-links-single<?php
                    if ( wanderic_get_theme_setting( 'thumbs_in_navigation' ) ) {
                        echo ' nav-links-with-thumbs';
                    }
                    if ( ! wanderic_is_off( wanderic_get_theme_option( 'posts_navigation_fixed' ) ) ) {
                        echo ' nav-links-fixed fixed';
                    }
                    ?>">
                        <?php
                        the_post_navigation(
                            array(
                                'next_text' => ( wanderic_get_theme_setting( 'thumbs_in_navigation' ) ? '<span class="nav-arrow"></span>' : '' )
                                    . '<span class="nav-arrow-label">' . esc_html__( 'Next', 'wanderic' ) . '</span> '
                                    . '<h6 class="post-title">%title</h6>',
                                'prev_text' => ( wanderic_get_theme_setting( 'thumbs_in_navigation' ) ? '<span class="nav-arrow"></span>' : '' )
                                    . '<span class="nav-arrow-label">' . esc_html__( 'Previous', 'wanderic' ) . '</span> '
                                    . '<h6 class="post-title">%title</h6>',
                            )
                        );
                        ?>
                    </div>
                    <?php
                    do_action( 'wanderic_action_after_post_navigation' );
                }

            }
        }
    }
}
// Add featured image as background image to post navigation elements.
if ( ! function_exists( 'wanderic_add_bg_in_post_nav' ) ) {
    function wanderic_add_bg_in_post_nav() {
        if ( ! is_single() || ! wanderic_get_theme_setting( 'thumbs_in_navigation' ) ) {
            return;
        }

        $previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
        $next     = get_adjacent_post( false, '', false );
        $css      = '';
        $noimg    = wanderic_get_no_image();

        if ( is_attachment() && 'attachment' == $previous->post_type ) {
            return;
        }

        if ( $previous ) {
            $img = '';
            if ( has_post_thumbnail( $previous->ID ) ) {
                $img = wp_get_attachment_image_src( get_post_thumbnail_id( $previous->ID ), wanderic_get_thumb_size( 'tiny' ) );
                $img = $img[0];
            } else {
                $img = $noimg;
            }
            if ( ! empty( $img ) ) {
                $css .= '.post-navigation .nav-previous a .nav-arrow { background-image: url(' . esc_url( $img ) . '); }';
            } else {
                $css .= '.nav-links-single .nav-links .nav-previous a { padding-left: 0 !important; }'
                    . '.post-navigation .nav-previous a .nav-arrow { display: none; background-color: rgba(128,128,128,0.05); border: 1px solid rgba(128,128,128,0.1); }'
                    . '.post-navigation .nav-previous a .nav-arrow:after { top: 0; opacity: 1; }';
            }
        }

        if ( $next ) {
            $img = '';
            if ( has_post_thumbnail( $next->ID ) ) {
                $img = wp_get_attachment_image_src( get_post_thumbnail_id( $next->ID ), wanderic_get_thumb_size( 'tiny' ) );
                $img = $img[0];
            } else {
                $img = $noimg;
            }
            if ( ! empty( $img ) ) {
                $css .= '.post-navigation .nav-next a .nav-arrow { background-image: url(' . esc_url( $img ) . '); }';
            } else {
                $css .= '.nav-links-single .nav-links .nav-next a { padding-right: 0 !important; }'
                    . '.post-navigation .nav-next a .nav-arrow { display: none; background-color: rgba(128,128,128,0.05); border: 1px solid rgba(128,128,128,0.1); }'
                    . '.post-navigation .nav-next a .nav-arrow:after { top: 0; opacity: 1; }';
            }
        }

        wanderic_add_inline_css( $css );
    }
}
if ( ! function_exists( 'wanderic_skin_customizer_theme_setup1' ) ) {
    add_action( 'after_setup_theme', 'wanderic_skin_customizer_theme_setup1', 1 );
    function wanderic_skin_customizer_theme_setup1() {
        wanderic_storage_set_array('settings', 'thumbs_in_navigation', true );
    }
}
if ( ! function_exists( 'wanderic_skin_woocommerce_theme_setup4' ) ) {
    add_action( 'after_setup_theme', 'wanderic_skin_woocommerce_theme_setup4', 4 );
    function wanderic_skin_woocommerce_theme_setup4() {
        wanderic_storage_set_array2('options', 'shop_hover', 'std', 'shop' );
        wanderic_storage_set_array2('options', 'related_posts_shop', 'std', 4 );
        wanderic_storage_set_array2('options', 'related_columns_shop', 'std', 4 );
        wanderic_storage_set_array2('options', 'sidebar_widgets_shop', 'std', 'woocommerce_widgets' );
        wanderic_storage_set_array2('options', 'sidebar_type_mobile', 'std', 'inherit' );
    }
}

/* Comments template */
// Callback for output single comment layout
if ( ! function_exists( 'wanderic_output_single_comment' ) ) {
    function wanderic_output_single_comment( $comment, $args, $depth ) {
        switch ( $comment->comment_type ) {
            case 'pingback':
                ?>
                <li class="trackback"><?php esc_html_e( 'Trackback:', 'wanderic' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( esc_html__( 'Edit', 'wanderic' ), '<span class="edit-link">', '<span>' ); ?>
                <?php
                break;
            case 'trackback':
                ?>
                <li class="pingback"><?php esc_html_e( 'Pingback:', 'wanderic' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( esc_html__( 'Edit', 'wanderic' ), '<span class="edit-link">', '<span>' ); ?>
                <?php
                break;
            default:
                $author_id   = $comment->user_id;
                $author_link = ! empty( $author_id ) ? get_author_posts_url( $author_id ) : '';
                $author_post = get_the_author_meta( 'ID' ) == $author_id;
                $mult        = wanderic_get_retina_multiplier();
                $comment_id  = get_comment_ID();
                ?>
            <li id="comment-<?php echo esc_attr( $comment_id ); ?>" <?php comment_class( 'comment_item' ); ?>>
                <div id="comment_body-<?php echo esc_attr( $comment_id ); ?>" class="comment_body">
                    <div class="comment_author_avatar"><?php echo get_avatar( $comment, 90 * $mult ); ?></div>
                    <div class="comment_content">
                        <div class="comment_info">
                            <h6 class="comment_author">
                                <?php
                                echo ( ! empty( $author_link ) ? '<a href="' . esc_url( $author_link ) . '">' : '' )
                                    . esc_html__( 'By ', 'wanderic' )
                                    . esc_html( get_comment_author() )
                                    . ( ! empty( $author_link ) ? '</a>' : '' );
                                ?>
                            </h6>
                            <div class="comment_posted">
                                <span class="comment_posted_label"><?php esc_html_e( 'Posted', 'wanderic' ); ?></span>
                                <span class="comment_date">
									<?php
                                    echo esc_html( get_comment_date( get_option( 'date_format' ) ) );
                                    ?>
									</span>
                                <span class="comment_time_label"><?php esc_html_e( 'at', 'wanderic' ); ?></span>
                                <span class="comment_time">
									<?php
                                    echo esc_html( get_comment_date( get_option( 'time_format' ) ) );
                                    ?>
									</span>
                            </div>
                            <?php
                            if ( $depth < $args['max_depth'] ) {
                                ?>
                                <span class="reply comment_reply">
										<?php
                                        comment_reply_link(
                                            array_merge(
                                                $args, array(
                                                    'add_below' => 'comment_body',
                                                    'depth' => $depth,
                                                    'max_depth' => $args['max_depth'],
                                                )
                                            )
                                        );
                                        ?>
									</span>
                                <?php
                            }
                            ?>
                        </div>
                        <div class="comment_text_wrap">
                            <?php if ( 0 == $comment->comment_approved ) { ?>
                                <div class="comment_not_approved"><?php esc_html_e( 'Your comment is awaiting moderation.', 'wanderic' ); ?></div>
                            <?php } ?>
                            <div class="comment_text"><?php comment_text(); ?></div>
                        </div>
                        <?php
                        // Show rating in the comment
                        do_action( 'trx_addons_action_post_rating', 'c' . esc_attr( $comment_id ) );
                        ?>
                    </div>
                </div>
                <?php
                break;
        }
    }
}
add_filter( 'trx_addons_filter_get_theme_accent_color', 'wanderic_skin_get_theme_accent_color',11 );

// Return theme-specific accent color
if ( ! function_exists( 'wanderic_skin_get_theme_accent_color' ) ) {
    function wanderic_skin_get_theme_accent_color( $color ) {
        return wanderic_get_scheme_color( 'text_link2' );
    }
}

// Return array with current system info
if ( ! function_exists( 'winger_trx_addons_get_sys_info' ) ) {
    add_filter( 'trx_addons_filter_get_sys_info', 'winger_trx_addons_get_sys_info', 10);
    function winger_trx_addons_get_sys_info( $arr ) {
        $arr['wp_version']['recommended'] = '5.0.0+';
        $arr['wp_version']['checked'] = version_compare( get_bloginfo( 'version' ), '5.0.0+', '>=' );
        $arr['php_version']['recommended'] = '7.0.0+';
        $arr['php_version']['checked'] = version_compare( phpversion(), '7.0.0+', '>=' );
        $arr['php_max_execution_time']['value'] = '300+';
        unset($arr['php_max_input_vars']);
        return $arr;
    }
}

if ( ! function_exists( 'wanderic_skin_get_list_hovers' ) ) {
    add_filter( 'wanderic_filter_list_hovers', 'wanderic_skin_get_list_hovers' );
    function wanderic_skin_get_list_hovers( $list ) {
        unset( $list['icons'] );
        unset( $list['fade'] );
        unset( $list['slide'] );
        unset( $list['pull'] );
        unset( $list['border'] );
        unset( $list['excerpt'] );
        unset( $list['info'] );
        return $list;
    }
}

remove_action('wp_footer', 'toastie_wc_smsb_social_footer');